
* ORIGINAL VARIABLES

** ccode: country numeric identifier (COW)
** year
** cgv_democracy: 1 if the country is democratic (source: Cheibub, Gandhi & Vreeland 2010)
** cgv_monarchy: 1 if the country is a monarchy (source: Cheibub, Gandhi & Vreeland 2010)
** cgv_military: 1 if the country is a military dictatorship (source: Cheibub, Gandhi & Vreeland 2010)
** onset1v414: dummy variable indicating a civil conflict outbreak (source: UCDP/PRIO Armed Conflict Dataset, 2017)
** incidencev414: dummy variable indicating an ongoing conflict (source: UCDP/PRIO Armed Conflict Dataset, 2017)
** peaceyears: number of years since the last conflict onset (source: UCDP/PRIO Armed Conflict Dataset, 2017)
** lpeaceyears: peace years lagged one year (source: UCDP/PRIO Armed Conflict Dataset, 2017)
** ht_region: world region (Hadenius & Teorell 2007; Quality of Government, 2017)
** wb_lifeexp: life expectancy at birth (World Development Indicators, 2017)
** termlimit: dummy variable indicating absolute term limits (Baturo 2016).
** population: population in million inhabitants (Penn World Table, 2015)
** leadername: leader's name (Archigos 4.1, 2016)
** yrborn: leader's birth year (Archigos 4.1, 2016)
** startyear: beginning of the leader spell (Archigos 4.1, 2016)
** entry: way of accessing power, regular/irregular/foreign imposition (Archigos 4.1, 2016)
** order: indicates the order of appearance of each leader for years in which several leaders are reported (Archigos 4.1, 2016)
** wb_gdppercapita_cur: GDP per capita, current USD (World Development Indicators, 2017)



* MAIN ESTIMATES (H1)

** Model 1

gen age = year-yrborn
gen yrinpower = year-startyear
gen sqpeace=lpeace*lpeace
gen cubpeace=lpeace*lpeace*lpeace
gen logpop=ln(population)
gen loggcap=ln(wb_gdppercapita_cur)
recode cgv_democracy(0=1)(1=0), gen(dictatorship)
gen agedict = age * dictatorship
logit onset1 lpeace sqpeace cubpeace age dictatorship agedict logpop loggcap wb_lifeexp ///
 yrin cgv_mil cgv_mon if order<2


** Model 2

gen exp_age = age*age
gen exp_agedict = dictatorship * exp_age
logit onset1 lpeace sqpeace cubpeace exp_age dictatorship exp_agedict logpop loggcap wb_lifeexp ///
 yrin cgv_mil cgv_mon if order<2


** Model 3

logit onset1 lpeace sqpeace cubpeace exp_age dictatorship exp_agedict logpop loggcap wb_lifeexp ///
 yrin cgv_mil cgv_mon if order<2, cluster(ccode)
 
 
** Model 4

logit onset1 lpeace sqpeace cubpeace exp_age dictatorship exp_agedict logpop loggcap wb_lifeexp ///
 yrin cgv_mil cgv_mon i.ht_region i.year if order<2
 

** Model 5

logit onset1 lpeace sqpeace cubpeace exp_age dictatorship exp_agedict logpop loggcap wb_lifeexp ///
 yrin cgv_mil cgv_mon i.ccode i.year if order<2
 
 
 
* VARIANTS (H2 TO H4)

** Model 6

preserve
drop exp_agedict
replace dictatorship=0 if termlimit==1
gen exp_agedict = exp_age*dictatorship
logit onset1 lpeace sqpeace cubpeace exp_age dictatorship exp_agedict logpop loggcap wb_lifeexp ///
 yrin cgv_mil cgv_mon i.ht_region i.year if order<2
restore


** Model 7
gen coupascw=.
* Note: these are coups d’état that resulted in >25 battle-deaths and thus appear in the UCDP/PRIO list of civil wars (see Powell & Thyne 2011).
replace coupascw=1 if ccode==145 & year==1952
replace coupascw=1 if ccode==150 & year==1954
replace coupascw=1 if ccode==150 & year==1989
replace coupascw=1 if ccode==90 & year==1949
replace coupascw=1 if ccode==90 & year==1954
replace coupascw=1 if ccode==800 & year==1951
replace coupascw=1 if ccode==160 & year==1963
replace coupascw=1 if ccode==645 & year==1958
replace coupascw=1 if ccode==645 & year==1959
replace coupascw=1 if ccode==645 & year==1963
replace coupascw=1 if ccode==530 & year==1960
replace coupascw=1 if ccode==101 & year==1962
replace coupascw=1 if ccode==481 & year==1964
replace coupascw=1 if ccode==516 & year==1965
replace coupascw=1 if ccode==42 & year==1965
replace coupascw=1 if ccode==452 & year==1966
replace coupascw=1 if ccode==475 & year==1966
replace coupascw=1 if ccode==652 & year==1966
replace coupascw=1 if ccode==625 & year==1971
replace coupascw=1 if ccode==625 & year==1976
replace coupascw=1 if ccode==600 & year==1971
replace coupascw=1 if ccode==500 & year==1971
replace coupascw=1 if ccode==92 & year==1972
replace coupascw=1 if ccode==155 & year==1973
replace coupascw=1 if ccode==520 & year==1978
replace coupascw=1 if ccode==411 & year==1979
replace coupascw=1 if ccode==450 & year==1980
replace coupascw=1 if ccode==420 & year==1981
replace coupascw=1 if ccode==501 & year==1982
replace coupascw=1 if ccode==471 & year==1984
replace coupascw=1 if ccode==461 & year==1991
replace coupascw=1 if ccode==680 & year==1986
replace coupascw=1 if ccode==439 & year==1987
replace coupascw=1 if ccode==581 & year==1989
replace coupascw=1 if ccode==95 & year==1989
replace coupascw=1 if ccode==41 & year==1989
replace coupascw=1 if ccode==41 & year==1991
replace coupascw=1 if ccode==373 & year==1995
replace coupascw=1 if ccode==700 & year==1978
replace coupascw=0 if coupascw!=1 & onset1!=.

logit coupascw lpeace sqpeace cubpeace exp_age dictatorship exp_agedict logpop loggcap wb_lifeexp ///
 yrin cgv_mil cgv_mon i.ht_region i.year if order<2
 

** Model 8

gen onset_clean = onset1 - coupascw
recode onset_clean (-1=0)
logit onset_clean lpeace sqpeace cubpeace exp_age dictatorship exp_agedict logpop loggcap wb_lifeexp ///
 yrin cgv_mil cgv_mon i.ht_region i.year if order<2

 
** Model 9

gen irregular = .
replace irregular = 1 if entry=="Irregular"
replace irregular = 0 if entry=="Regular"
gen age_irregular = exp_age*irregular
logit onset1 lpeace sqpeace cubpeace exp_age irregular age_irreg logpop loggcap wb_lifeexp ///
yrin cgv_mil cgv_mon i.year i.ht_region if dictatorship ==1 & order<2



* ROBUSTNESS CHECKS

** Model 10

logit onset1 lpeace sqpeace cubpeace exp_age dictatorship exp_agedict logpop loggcap wb_lifeexp ///
 yrin cgv_mil cgv_mon i.ht_region i.year if order<2
predict dbeta, dbeta
logit onset1 lpeace sqpeace cubpeace exp_age dictatorship exp_agedict logpop loggcap wb_lifeexp ///
 yrin cgv_mil cgv_mon i.ht_region i.year if order<2 & dbeta<1
 
 
** Model 11

logit onset1 lpeace sqpeace cubpeace exp_age dictatorship exp_agedict logpop loggcap wb_lifeexp ///
 yrin cgv_mil cgv_mon i.ht_region i.year if order<2 & dbeta<0.2
 
 
** Model 12

logit onset1 lpeace sqpeace cubpeace exp_age dictatorship exp_agedict logpop loggcap wb_lifeexp ///
 yrin cgv_mil cgv_mon i.ht_region i.year if order<2 & age>39
 

** Model 13

sort ccode year 
egen conflict=total(incidence), by(ccode)
preserve
drop if conflict==0
logit onset1 lpeace sqpeace cubpeace exp_age dictatorship exp_agedict logpop loggcap wb_lifeexp ///
 yrin cgv_mil cgv_mon i.ht_region i.year if order<2
restore


** Model 14

logit onset1 lpeace sqpeace cubpeace exp_age dictatorship exp_agedict logpop loggcap wb_lifeexp ///
 yrin cgv_mil cgv_mon i.ht_region i.year if order<2 & peaceyears<21
 

 ** Model 15

logit onset1 lpeace sqpeace cubpeace exp_age dictatorship exp_agedict logpop loggcap wb_lifeexp ///
 yrin cgv_mil cgv_mon i.ht_region i.year if order<2 & peaceyears<11

